==> nemonet-0.7.32.tar.gz: nemonet-0.7.32/nemonet/seleniumwebdriver/abstract_command.py <==
import logging
import time
from abc import ABC, abstractmethod
from datetime import datetime
import uuid

from nemonet.engines.graph import Action
from nemonet.seleniumwebdriver.page_capture import PageCapturing
from nemonet.engines.cache_store import KeyValueStore

class AbstractCommand(ABC):

    @abstractmethod
    def execute_action(self, action: Action, driver):
        pass  # does nothing by default

    def execute(self, action: Action, driver, sleep_time=0.25, filename=None):
        """ Executes given action as a vision command """

        self.__sleep(sleep_time)
        self.__screenshot(action, driver)
        self.__log(str(action))
        self.execute_action(action, driver)
        self.__sleep(sleep_time)
        self.__screenshot(action, driver)
        self.__sleep(action.get_wait_after())

    def log(self, string):
        self.__log(string)

    def sleep(self, second):
        self.__sleep(second)

    def __screenshot(self, action, driver):
        """ Takes a screenshot of the current state of [ TERMINOLOGY ] using given driver
            and saves it as a .png file with given filename [ WHERE? ].
            Fails silently when given filename is None. """

        kv_store = KeyValueStore()
        value_true_false = kv_store.get_value_as_str("VISION_ENV_SCREENSHOTS")
        kv_store.close()

        if value_true_false.lower() == 'false':
            return

        if action == None:
            return

        if action.getElementType() == 'SCREENSHOT':
            return

        capture = PageCapturing(driver)
        now = datetime.now()
        filename = "screenshot_" + now.strftime("%Y%m%d-%H%M%S.%f") + "-" \
                   + action.getElementType() + "-" \
                   + str(uuid.uuid4()) + ".png"
        capture.capture_save(file_name_cpatured=filename)

    def __sleep(self, seconds):
        time.sleep(seconds)

    def __log(self, string):
        # TODO : recomputation should be avoided
        # set up
        logger = logging.getLogger('vision_logger')
        logger.setLevel(logging.DEBUG)
        fh = logging.FileHandler('vision.log')
        formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
        fh.setFormatter(formatter)
        logger.addHandler(fh)

        # log
        logger.debug(string)

==> nemonet-0.18.3.tar.gz: nemonet-0.18.3/nemonet/seleniumwebdriver/abstract_command.py <==
import logging
logger = logging.getLogger(__name__)

import time
from abc import ABC, abstractmethod
from datetime import datetime
import uuid

from nemonet.engines.graph import Action
from nemonet.seleniumwebdriver.page_capture import PageCapturing
from nemonet.engines.cache_store import KeyValueStore

class AbstractCommand(ABC):

    @abstractmethod
    def execute_action(self, action: Action, driver):
        pass  # does nothing by default

    def set_image_recorder(self, image_recorder):
        self.image_recorder = image_recorder

    def execute(self, action: Action, driver, sleep_time=0.25, filename=None):
        """ Executes given action as a vision command """

        self.__sleep(sleep_time)
        self.__screenshot(action, driver)
        self.__log(str(action))
        self.execute_action(action, driver)
        self.__sleep(sleep_time)
        self.__screenshot(action, driver)
        self.__sleep(action.get_wait_after())

    def log(self, string):
        self.__log(string)

    def sleep(self, second):
        self.__sleep(second)

    def __screenshot(self, action, driver):
        """ Takes a screenshot of the current state of [ TERMINOLOGY ] using given driver
            and saves it as a .png file with given filename [ WHERE? ].
            Fails silently when given filename is None. """
        if action == None:
            return
        if action.getElementType() == 'SCREENSHOT':
            return
        if not self.image_recorder.is_enabled():
            return
        capture = PageCapturing(driver)
        capture.capture_save(file_name_cpatured=self.image_recorder.generate_screenshot_filename(action.getElementType()))

    def __sleep(self, seconds):
        time.sleep(seconds)

    def __log(self, string):
        # TODO : recomputation should be avoided
        # set up
        # log
        logger.debug(string)
